# Generated by Django 5.2.8 on 2025-11-30 18:31

import django_ai_validator.fields
import django_ai_validator.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='TestModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content', django_ai_validator.fields.AICleanedField(blank=True, cleaning_prompt='Clean this')),
                ('validated_content', models.CharField(blank=True, max_length=100, validators=[django_ai_validator.validators.AISemanticValidator(prompt_template='Validate this')])),
            ],
        ),
    ]
